summaryrefslogtreecommitdiffstats
path: root/korganizer/koeventview.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeventview.h')
-rw-r--r--korganizer/koeventview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/korganizer/koeventview.h b/korganizer/koeventview.h
index 0a29e0c9..303486c4 100644
--- a/korganizer/koeventview.h
+++ b/korganizer/koeventview.h
@@ -62,10 +62,10 @@ class KOEventView : public KOrg::BaseView
* Constructs a view.
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
* @param tqparent is the tqparent TQWidget.
* @param name is the view name.
*/
- KOEventView(Calendar *cal,TQWidget *tqparent=0,const char *name=0);
+ KOEventView(Calendar *cal,TQWidget *parent=0,const char *name=0);
/**
* Destructor. Views will do view-specific cleanups here.
@@ -62,10 +62,10 @@ class KOEventView : public KOrg::BaseView
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
- * @param tqparent is the tqparent TQWidget.
+ * @param parent is the parent TQWidget.
* @param name is the view name.
*/